@@ -34,7 +34,11 @@ send_initial_message(struct lws *wsi) {
     if (lws_write(wsi, p, (size_t) n, LWS_WRITE_TEXT) < n) {
         return -1;
     }
-
+    // client preferences
+    n = sprintf((char *) p, "%c%s", SET_PREFERENCES, server->prefs_json);
+    if (lws_write(wsi, p, (size_t) n, LWS_WRITE_TEXT) < n) {
+        return -1;
+    }
     return 0;
 }
 
@@ -45,15 +49,16 @@ parse_window_size(const char *json) {
     struct json_object *o = NULL;
 
     if (!json_object_object_get_ex(obj, "columns", &o)) {
-        lwsl_err("columns field not exists!");
+        lwsl_err("columns field not exists!\n");
         return NULL;
     }
     columns = json_object_get_int(o);
     if (!json_object_object_get_ex(obj, "rows", &o)) {
-        lwsl_err("rows field not exists!");
+        lwsl_err("rows field not exists!\n");
         return NULL;
     }
     rows = json_object_get_int(o);
+    json_object_put(obj);
 
     struct winsize *size = t_malloc(sizeof(struct winsize));
     memset(size, 0, sizeof(struct winsize));
